@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Tester
 #
-# This software is Copyright (c) 2013-2017 by Dominique Dumont.
+# This software is Copyright (c) 2013-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package Config::Model::Tester;
 # ABSTRACT: Test framework for Config::Model
-$Config::Model::Tester::VERSION = '3.002';
+$Config::Model::Tester::VERSION = '3.004';
 use warnings;
 use strict;
 use locale;
@@ -56,6 +56,9 @@ sub setup_test {
 
     my $wr_dir    = $wr_root->child('test-' . $t_name);
     my $wr_dir2   = $wr_root->child('test-' . $t_name.'-w');
+    $wr_dir->mkpath;
+    $wr_dir2->mkpath;
+
     my $conf_file ;
     $conf_file = $wr_dir->child($conf_dir,$conf_file_name)
         if $conf_dir and $conf_file_name;
@@ -350,7 +353,7 @@ sub check_file_content {
             my $t = $fc->{$f} ;
             my @tests = ref $t eq 'ARRAY' ? @$t : ($t) ;
             foreach my $subtest (@tests) {
-                file_contents_eq_or_diff $wr_dir->child($f)->stringify,  $subtest,
+                file_contents_eq_or_diff $wr_dir->child($f)->stringify,  $subtest, { encoding => 'UTF-8' },
                     "check that $f contains $subtest";
             }
         }
@@ -361,7 +364,7 @@ sub check_file_content {
             my $t = $fc->{$f} ;
             my @tests = ref $t eq 'ARRAY' ? @$t : ($t) ;
             foreach my $subtest (@tests) {
-                file_contents_like $wr_dir->child($f)->stringify,  $subtest,
+                file_contents_like $wr_dir->child($f)->stringify,  $subtest, { encoding => 'UTF-8' },
                     "check that $f matches regexp $subtest";
             }
         }
@@ -372,7 +375,7 @@ sub check_file_content {
             my $t = $fc->{$f} ;
             my @tests = ref $t eq 'ARRAY' ? @$t : ($t) ;
             foreach my $subtest (@tests) {
-                file_contents_unlike $wr_dir->child($f)->stringify,  $subtest,
+                file_contents_unlike $wr_dir->child($f)->stringify,  $subtest, { encoding => 'UTF-8' },
                     "check that $f does not match regexp $subtest";
             }
         }
@@ -488,8 +491,12 @@ sub run_model_test {
         my @options;
         push @options, backend_arg => $t->{backend_arg} if $t->{backend_arg};
 
+        # eventually, we may end up with several instances of Dpkg
+        # model in the same process. So we can't play with chdir
         my $inst = $model->instance(
             root_class_name => $model_to_test,
+            # need to keed root_dir to handle config files like
+            # /etc/foo.ini (absolute path, like in /etc/)
             root_dir        => $wr_dir->stringify,
             instance_name   => $inst_name,
             application     => $app_to_test,
@@ -535,7 +542,7 @@ sub run_model_test {
 
         load_instructions ($i2_root,$t->{load2},$trace) if $t->{load2} ;
 
-        my $p2_dump = dump_tree("second $app_to_test", $i2_root, 'custom', $t->{no_warnings},{}) ;
+        my $p2_dump = dump_tree("second $app_to_test", $i2_root, 'custom', $t->{no_warnings},{}, $trace) ;
 
         unified_diff;
         eq_or_diff(
@@ -627,7 +634,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 3.002
+version 3.004
 
 =head1 SYNOPSIS
 
@@ -1268,7 +1275,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013-2017 by Dominique Dumont.
+This software is Copyright (c) 2013-2018 by Dominique Dumont.
 
 This is free software, licensed under:
 
@@ -1321,7 +1328,7 @@ L<http://cpants.cpanauthors.org/dist/Config-Model-Tester>
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/C/Config-Model-Tester>
 
